/* ---------------------------------------------------------------------------- */
/*                  Atmel Microcontroller Software Support                      */
/*                       SAM Software Package License                           */
/* ---------------------------------------------------------------------------- */
/* Copyright (c) 2013, Atmel Corporation                                        */
/*                                                                              */
/* All rights reserved.                                                         */
/*                                                                              */
/* Redistribution and use in source and binary forms, with or without           */
/* modification, are permitted provided that the following condition is met:    */
/*                                                                              */
/* - Redistributions of source code must retain the above copyright notice,     */
/* this list of conditions and the disclaimer below.                            */
/*                                                                              */
/* Atmel's name may not be used to endorse or promote products derived from     */
/* this software without specific prior written permission.                     */
/*                                                                              */
/* DISCLAIMER:  THIS SOFTWARE IS PROVIDED BY ATMEL "AS IS" AND ANY EXPRESS OR   */
/* IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF */
/* MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT ARE   */
/* DISCLAIMED. IN NO EVENT SHALL ATMEL BE LIABLE FOR ANY DIRECT, INDIRECT,      */
/* INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT */
/* LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,  */
/* OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF    */
/* LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING         */
/* NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, */
/* EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.                           */
/* ---------------------------------------------------------------------------- */

#ifndef _SAM4CP16B_SPI1_COMPONENT_
#define _SAM4CP16B_SPI1_COMPONENT_

/* ============================================================================= */
/**  SOFTWARE API DEFINITION FOR PRIME Power Line Communication (PPLC) Transceiver */
/* ============================================================================= */
/** \addtogroup SAM4CP16B_SPI1 PRIME Power Line Communication (PPLC) Transceiver */
/*@{*/

#if !(defined(__ASSEMBLY__) || defined(__IAR_SYSTEMS_ASM__))
/** \brief Spi1 hardware registers */
typedef struct {
  __O  uint32_t SPI1_CR;       /**< \brief (Spi1 Offset: 0x00) Control Register */
  __IO uint32_t SPI1_MR;       /**< \brief (Spi1 Offset: 0x04) Mode Register */
  __I  uint32_t SPI1_RDR;      /**< \brief (Spi1 Offset: 0x08) Receive Data Register */
  __O  uint32_t SPI1_TDR;      /**< \brief (Spi1 Offset: 0x0C) Transmit Data Register */
  __I  uint32_t SPI1_SR;       /**< \brief (Spi1 Offset: 0x10) Status Register */
  __O  uint32_t SPI1_IER;      /**< \brief (Spi1 Offset: 0x14) Interrupt Enable Register */
  __O  uint32_t SPI1_IDR;      /**< \brief (Spi1 Offset: 0x18) Interrupt Disable Register */
  __I  uint32_t SPI1_IMR;      /**< \brief (Spi1 Offset: 0x1C) Interrupt Mask Register */
  __I  uint32_t Reserved1[4];
  __IO uint32_t SPI1_CSR;      /**< \brief (Spi1 Offset: 0x30) Chip Select Register */
  __I  uint32_t Reserved2[44];
  __IO uint32_t SPI1_WPMR;     /**< \brief (Spi1 Offset: 0xE4) Write Protection Control Register */
  __I  uint32_t SPI1_WPSR;     /**< \brief (Spi1 Offset: 0xE8) Write Protection Status Register */
  __I  uint32_t Reserved3[5];
  __IO uint32_t SPI1_RPR;      /**< \brief (Spi1 Offset: 0x100) Receive Pointer Register */
  __IO uint32_t SPI1_RCR;      /**< \brief (Spi1 Offset: 0x104) Receive Counter Register */
  __IO uint32_t SPI1_TPR;      /**< \brief (Spi1 Offset: 0x108) Transmit Pointer Register */
  __IO uint32_t SPI1_TCR;      /**< \brief (Spi1 Offset: 0x10C) Transmit Counter Register */
  __IO uint32_t SPI1_RNPR;     /**< \brief (Spi1 Offset: 0x110) Receive Next Pointer Register */
  __IO uint32_t SPI1_RNCR;     /**< \brief (Spi1 Offset: 0x114) Receive Next Counter Register */
  __IO uint32_t SPI1_TNPR;     /**< \brief (Spi1 Offset: 0x118) Transmit Next Pointer Register */
  __IO uint32_t SPI1_TNCR;     /**< \brief (Spi1 Offset: 0x11C) Transmit Next Counter Register */
  __O  uint32_t SPI1_PTCR;     /**< \brief (Spi1 Offset: 0x120) Transfer Control Register */
  __I  uint32_t SPI1_PTSR;     /**< \brief (Spi1 Offset: 0x124) Transfer Status Register */
} Spi1;
#endif /* !(defined(__ASSEMBLY__) || defined(__IAR_SYSTEMS_ASM__)) */
/* -------- SPI1_CR : (SPI1 Offset: 0x00) Control Register -------- */
#define SPI1_CR_PPLCEN (0x1u << 0) /**< \brief (SPI1_CR) PPLC Enable */
#define SPI1_CR_PPLCDIS (0x1u << 1) /**< \brief (SPI1_CR) PPLC Disable */
#define SPI1_CR_SWRST (0x1u << 7) /**< \brief (SPI1_CR) PPLC Software Reset */
#define SPI1_CR_LASTXFER (0x1u << 24) /**< \brief (SPI1_CR) Last Transfer */
/* -------- SPI1_MR : (SPI1 Offset: 0x04) Mode Register -------- */
#define SPI1_MR_MSTR (0x1u << 0) /**< \brief (SPI1_MR) Active Mode */
#define SPI1_MR_PS (0x1u << 1) /**< \brief (SPI1_MR) Peripheral Select */
#define SPI1_MR_PCSDEC (0x1u << 2) /**< \brief (SPI1_MR) Chip Select Decode */
#define SPI1_MR_MODFDIS (0x1u << 4) /**< \brief (SPI1_MR) Mode Fault Detection */
#define SPI1_MR_WDRBT (0x1u << 5) /**< \brief (SPI1_MR) Wait Data Read Before Transfer */
#define SPI1_MR_LLB (0x1u << 7) /**< \brief (SPI1_MR) Local Loopback Enable */
#define SPI1_MR_PCS_Pos 16
#define SPI1_MR_PCS_Msk (0xfu << SPI1_MR_PCS_Pos) /**< \brief (SPI1_MR) Peripheral Chip Select */
#define SPI1_MR_PCS(value) ((SPI1_MR_PCS_Msk & ((value) << SPI1_MR_PCS_Pos)))
#define SPI1_MR_DLYBCS_Pos 24
#define SPI1_MR_DLYBCS_Msk (0xffu << SPI1_MR_DLYBCS_Pos) /**< \brief (SPI1_MR) Delay Between Chip Selects */
#define SPI1_MR_DLYBCS(value) ((SPI1_MR_DLYBCS_Msk & ((value) << SPI1_MR_DLYBCS_Pos)))
/* -------- SPI1_RDR : (SPI1 Offset: 0x08) Receive Data Register -------- */
#define SPI1_RDR_RD_Pos 0
#define SPI1_RDR_RD_Msk (0xffffu << SPI1_RDR_RD_Pos) /**< \brief (SPI1_RDR) Receive Data */
#define SPI1_RDR_PCS_Pos 16
#define SPI1_RDR_PCS_Msk (0xfu << SPI1_RDR_PCS_Pos) /**< \brief (SPI1_RDR) Peripheral Chip Select */
/* -------- SPI1_TDR : (SPI1 Offset: 0x0C) Transmit Data Register -------- */
#define SPI1_TDR_TD_Pos 0
#define SPI1_TDR_TD_Msk (0xffffu << SPI1_TDR_TD_Pos) /**< \brief (SPI1_TDR) Transmit Data */
#define SPI1_TDR_TD(value) ((SPI1_TDR_TD_Msk & ((value) << SPI1_TDR_TD_Pos)))
#define SPI1_TDR_PCS_Pos 16
#define SPI1_TDR_PCS_Msk (0xfu << SPI1_TDR_PCS_Pos) /**< \brief (SPI1_TDR) Peripheral Chip Select */
#define SPI1_TDR_PCS(value) ((SPI1_TDR_PCS_Msk & ((value) << SPI1_TDR_PCS_Pos)))
#define SPI1_TDR_LASTXFER (0x1u << 24) /**< \brief (SPI1_TDR) Last Transfer */
/* -------- SPI1_SR : (SPI1 Offset: 0x10) Status Register -------- */
#define SPI1_SR_RDRF (0x1u << 0) /**< \brief (SPI1_SR) Receive Data Register Full */
#define SPI1_SR_TDRE (0x1u << 1) /**< \brief (SPI1_SR) Transmit Data Register Empty */
#define SPI1_SR_MODF (0x1u << 2) /**< \brief (SPI1_SR) Mode Fault Error */
#define SPI1_SR_OVRES (0x1u << 3) /**< \brief (SPI1_SR) Overrun Error Status */
#define SPI1_SR_ENDRX (0x1u << 4) /**< \brief (SPI1_SR) End of RX buffer */
#define SPI1_SR_ENDTX (0x1u << 5) /**< \brief (SPI1_SR) End of TX buffer */
#define SPI1_SR_RXBUFF (0x1u << 6) /**< \brief (SPI1_SR) RX Buffer Full */
#define SPI1_SR_TXBUFE (0x1u << 7) /**< \brief (SPI1_SR) TX Buffer Empty */
#define SPI1_SR_NSSR (0x1u << 8) /**< \brief (SPI1_SR) NSS Rising */
#define SPI1_SR_TXEMPTY (0x1u << 9) /**< \brief (SPI1_SR) Transmission Registers Empty */
#define SPI1_SR_UNDES (0x1u << 10) /**< \brief (SPI1_SR) Underrun Error Status (Slave Mode Only) */
#define SPI1_SR_PPLCENS (0x1u << 16) /**< \brief (SPI1_SR) PPLC Enable Status */
/* -------- SPI1_IER : (SPI1 Offset: 0x14) Interrupt Enable Register -------- */
#define SPI1_IER_RDRF (0x1u << 0) /**< \brief (SPI1_IER) Receive Data Register Full Interrupt Enable */
#define SPI1_IER_TDRE (0x1u << 1) /**< \brief (SPI1_IER) PPLC Transmit Data Register Empty Interrupt Enable */
#define SPI1_IER_MODF (0x1u << 2) /**< \brief (SPI1_IER) Mode Fault Error Interrupt Enable */
#define SPI1_IER_OVRES (0x1u << 3) /**< \brief (SPI1_IER) Overrun Error Interrupt Enable */
#define SPI1_IER_ENDRX (0x1u << 4) /**< \brief (SPI1_IER) End of Receive Buffer Interrupt Enable */
#define SPI1_IER_ENDTX (0x1u << 5) /**< \brief (SPI1_IER) End of Transmit Buffer Interrupt Enable */
#define SPI1_IER_RXBUFF (0x1u << 6) /**< \brief (SPI1_IER) Receive Buffer Full Interrupt Enable */
#define SPI1_IER_TXBUFE (0x1u << 7) /**< \brief (SPI1_IER) Transmit Buffer Empty Interrupt Enable */
#define SPI1_IER_NSSR (0x1u << 8) /**< \brief (SPI1_IER) NSS Rising Interrupt Enable */
#define SPI1_IER_TXEMPTY (0x1u << 9) /**< \brief (SPI1_IER) Transmission Registers Empty Enable */
#define SPI1_IER_UNDES (0x1u << 10) /**< \brief (SPI1_IER) Underrun Error Interrupt Enable */
/* -------- SPI1_IDR : (SPI1 Offset: 0x18) Interrupt Disable Register -------- */
#define SPI1_IDR_RDRF (0x1u << 0) /**< \brief (SPI1_IDR) Receive Data Register Full Interrupt Disable */
#define SPI1_IDR_TDRE (0x1u << 1) /**< \brief (SPI1_IDR) PPLC Transmit Data Register Empty Interrupt Disable */
#define SPI1_IDR_MODF (0x1u << 2) /**< \brief (SPI1_IDR) Mode Fault Error Interrupt Disable */
#define SPI1_IDR_OVRES (0x1u << 3) /**< \brief (SPI1_IDR) Overrun Error Interrupt Disable */
#define SPI1_IDR_ENDRX (0x1u << 4) /**< \brief (SPI1_IDR) End of Receive Buffer Interrupt Disable */
#define SPI1_IDR_ENDTX (0x1u << 5) /**< \brief (SPI1_IDR) End of Transmit Buffer Interrupt Disable */
#define SPI1_IDR_RXBUFF (0x1u << 6) /**< \brief (SPI1_IDR) Receive Buffer Full Interrupt Disable */
#define SPI1_IDR_TXBUFE (0x1u << 7) /**< \brief (SPI1_IDR) Transmit Buffer Empty Interrupt Disable */
#define SPI1_IDR_NSSR (0x1u << 8) /**< \brief (SPI1_IDR) NSS Rising Interrupt Disable */
#define SPI1_IDR_TXEMPTY (0x1u << 9) /**< \brief (SPI1_IDR) Transmission Registers Empty Disable */
#define SPI1_IDR_UNDES (0x1u << 10) /**< \brief (SPI1_IDR) Underrun Error Interrupt Disable */
/* -------- SPI1_IMR : (SPI1 Offset: 0x1C) Interrupt Mask Register -------- */
#define SPI1_IMR_RDRF (0x1u << 0) /**< \brief (SPI1_IMR) Receive Data Register Full Interrupt Mask */
#define SPI1_IMR_TDRE (0x1u << 1) /**< \brief (SPI1_IMR) PPLC Transmit Data Register Empty Interrupt Mask */
#define SPI1_IMR_MODF (0x1u << 2) /**< \brief (SPI1_IMR) Mode Fault Error Interrupt Mask */
#define SPI1_IMR_OVRES (0x1u << 3) /**< \brief (SPI1_IMR) Overrun Error Interrupt Mask */
#define SPI1_IMR_ENDRX (0x1u << 4) /**< \brief (SPI1_IMR) End of Receive Buffer Interrupt Mask */
#define SPI1_IMR_ENDTX (0x1u << 5) /**< \brief (SPI1_IMR) End of Transmit Buffer Interrupt Mask */
#define SPI1_IMR_RXBUFF (0x1u << 6) /**< \brief (SPI1_IMR) Receive Buffer Full Interrupt Mask */
#define SPI1_IMR_TXBUFE (0x1u << 7) /**< \brief (SPI1_IMR) Transmit Buffer Empty Interrupt Mask */
#define SPI1_IMR_NSSR (0x1u << 8) /**< \brief (SPI1_IMR) NSS Rising Interrupt Mask */
#define SPI1_IMR_TXEMPTY (0x1u << 9) /**< \brief (SPI1_IMR) Transmission Registers Empty Mask */
#define SPI1_IMR_UNDES (0x1u << 10) /**< \brief (SPI1_IMR) Underrun Error Interrupt Mask */
/* -------- SPI1_CSR : (SPI1 Offset: 0x30) Chip Select Register -------- */
#define SPI1_CSR_CPOL (0x1u << 0) /**< \brief (SPI1_CSR) Clock Polarity */
#define SPI1_CSR_NCPHA (0x1u << 1) /**< \brief (SPI1_CSR) Clock Phase */
#define SPI1_CSR_CSNAAT (0x1u << 2) /**< \brief (SPI1_CSR) Chip Select Not Active After Transfer (Ignored if CSAAT = 1) */
#define SPI1_CSR_CSAAT (0x1u << 3) /**< \brief (SPI1_CSR) Chip Select Active After Transfer */
#define SPI1_CSR_BITS_Pos 4
#define SPI1_CSR_BITS_Msk (0xfu << SPI1_CSR_BITS_Pos) /**< \brief (SPI1_CSR) Bits Per Transfer */
#define SPI1_CSR_BITS(value) ((SPI1_CSR_BITS_Msk & ((value) << SPI1_CSR_BITS_Pos)))
#define SPI1_CSR_SCBR_Pos 8
#define SPI1_CSR_SCBR_Msk (0xffu << SPI1_CSR_SCBR_Pos) /**< \brief (SPI1_CSR) Serial Clock Baud Rate */
#define SPI1_CSR_SCBR(value) ((SPI1_CSR_SCBR_Msk & ((value) << SPI1_CSR_SCBR_Pos)))
#define SPI1_CSR_DLYBS_Pos 16
#define SPI1_CSR_DLYBS_Msk (0xffu << SPI1_CSR_DLYBS_Pos) /**< \brief (SPI1_CSR) Delay Before SPCK */
#define SPI1_CSR_DLYBS(value) ((SPI1_CSR_DLYBS_Msk & ((value) << SPI1_CSR_DLYBS_Pos)))
#define SPI1_CSR_DLYBCT_Pos 24
#define SPI1_CSR_DLYBCT_Msk (0xffu << SPI1_CSR_DLYBCT_Pos) /**< \brief (SPI1_CSR) Delay Between Consecutive Transfers */
#define SPI1_CSR_DLYBCT(value) ((SPI1_CSR_DLYBCT_Msk & ((value) << SPI1_CSR_DLYBCT_Pos)))
/* -------- SPI1_WPMR : (SPI1 Offset: 0xE4) Write Protection Control Register -------- */
#define SPI1_WPMR_WPEN (0x1u << 0) /**< \brief (SPI1_WPMR) Write Protection Enable */
#define SPI1_WPMR_WPKEY_Pos 8
#define SPI1_WPMR_WPKEY_Msk (0xffffffu << SPI1_WPMR_WPKEY_Pos) /**< \brief (SPI1_WPMR) Write Protection Key Password */
#define SPI1_WPMR_WPKEY(value) ((SPI1_WPMR_WPKEY_Msk & ((value) << SPI1_WPMR_WPKEY_Pos)))
/* -------- SPI1_WPSR : (SPI1 Offset: 0xE8) Write Protection Status Register -------- */
#define SPI1_WPSR_WPVS (0x1u << 0) /**< \brief (SPI1_WPSR) Write Protection Violation Status */
#define SPI1_WPSR_WPVSRC_Pos 8
#define SPI1_WPSR_WPVSRC_Msk (0xffu << SPI1_WPSR_WPVSRC_Pos) /**< \brief (SPI1_WPSR) Write Protection Violation Source */
/* -------- SPI1_RPR : (SPI1 Offset: 0x100) Receive Pointer Register -------- */
#define SPI1_RPR_RXPTR_Pos 0
#define SPI1_RPR_RXPTR_Msk (0xffffffffu << SPI1_RPR_RXPTR_Pos) /**< \brief (SPI1_RPR) Receive Pointer Register */
#define SPI1_RPR_RXPTR(value) ((SPI1_RPR_RXPTR_Msk & ((value) << SPI1_RPR_RXPTR_Pos)))
/* -------- SPI1_RCR : (SPI1 Offset: 0x104) Receive Counter Register -------- */
#define SPI1_RCR_RXCTR_Pos 0
#define SPI1_RCR_RXCTR_Msk (0xffffu << SPI1_RCR_RXCTR_Pos) /**< \brief (SPI1_RCR) Receive Counter Register */
#define SPI1_RCR_RXCTR(value) ((SPI1_RCR_RXCTR_Msk & ((value) << SPI1_RCR_RXCTR_Pos)))
/* -------- SPI1_TPR : (SPI1 Offset: 0x108) Transmit Pointer Register -------- */
#define SPI1_TPR_TXPTR_Pos 0
#define SPI1_TPR_TXPTR_Msk (0xffffffffu << SPI1_TPR_TXPTR_Pos) /**< \brief (SPI1_TPR) Transmit Counter Register */
#define SPI1_TPR_TXPTR(value) ((SPI1_TPR_TXPTR_Msk & ((value) << SPI1_TPR_TXPTR_Pos)))
/* -------- SPI1_TCR : (SPI1 Offset: 0x10C) Transmit Counter Register -------- */
#define SPI1_TCR_TXCTR_Pos 0
#define SPI1_TCR_TXCTR_Msk (0xffffu << SPI1_TCR_TXCTR_Pos) /**< \brief (SPI1_TCR) Transmit Counter Register */
#define SPI1_TCR_TXCTR(value) ((SPI1_TCR_TXCTR_Msk & ((value) << SPI1_TCR_TXCTR_Pos)))
/* -------- SPI1_RNPR : (SPI1 Offset: 0x110) Receive Next Pointer Register -------- */
#define SPI1_RNPR_RXNPTR_Pos 0
#define SPI1_RNPR_RXNPTR_Msk (0xffffffffu << SPI1_RNPR_RXNPTR_Pos) /**< \brief (SPI1_RNPR) Receive Next Pointer */
#define SPI1_RNPR_RXNPTR(value) ((SPI1_RNPR_RXNPTR_Msk & ((value) << SPI1_RNPR_RXNPTR_Pos)))
/* -------- SPI1_RNCR : (SPI1 Offset: 0x114) Receive Next Counter Register -------- */
#define SPI1_RNCR_RXNCTR_Pos 0
#define SPI1_RNCR_RXNCTR_Msk (0xffffu << SPI1_RNCR_RXNCTR_Pos) /**< \brief (SPI1_RNCR) Receive Next Counter */
#define SPI1_RNCR_RXNCTR(value) ((SPI1_RNCR_RXNCTR_Msk & ((value) << SPI1_RNCR_RXNCTR_Pos)))
/* -------- SPI1_TNPR : (SPI1 Offset: 0x118) Transmit Next Pointer Register -------- */
#define SPI1_TNPR_TXNPTR_Pos 0
#define SPI1_TNPR_TXNPTR_Msk (0xffffffffu << SPI1_TNPR_TXNPTR_Pos) /**< \brief (SPI1_TNPR) Transmit Next Pointer */
#define SPI1_TNPR_TXNPTR(value) ((SPI1_TNPR_TXNPTR_Msk & ((value) << SPI1_TNPR_TXNPTR_Pos)))
/* -------- SPI1_TNCR : (SPI1 Offset: 0x11C) Transmit Next Counter Register -------- */
#define SPI1_TNCR_TXNCTR_Pos 0
#define SPI1_TNCR_TXNCTR_Msk (0xffffu << SPI1_TNCR_TXNCTR_Pos) /**< \brief (SPI1_TNCR) Transmit Counter Next */
#define SPI1_TNCR_TXNCTR(value) ((SPI1_TNCR_TXNCTR_Msk & ((value) << SPI1_TNCR_TXNCTR_Pos)))
/* -------- SPI1_PTCR : (SPI1 Offset: 0x120) Transfer Control Register -------- */
#define SPI1_PTCR_RXTEN (0x1u << 0) /**< \brief (SPI1_PTCR) Receiver Transfer Enable */
#define SPI1_PTCR_RXTDIS (0x1u << 1) /**< \brief (SPI1_PTCR) Receiver Transfer Disable */
#define SPI1_PTCR_TXTEN (0x1u << 8) /**< \brief (SPI1_PTCR) Transmitter Transfer Enable */
#define SPI1_PTCR_TXTDIS (0x1u << 9) /**< \brief (SPI1_PTCR) Transmitter Transfer Disable */
/* -------- SPI1_PTSR : (SPI1 Offset: 0x124) Transfer Status Register -------- */
#define SPI1_PTSR_RXTEN (0x1u << 0) /**< \brief (SPI1_PTSR) Receiver Transfer Enable */
#define SPI1_PTSR_TXTEN (0x1u << 8) /**< \brief (SPI1_PTSR) Transmitter Transfer Enable */

/*@}*/


#endif /* _SAM4CP16B_SPI1_COMPONENT_ */
